@@ -8,7 +8,7 @@ use lz4_flex as lz4;
 pub enum InternalError {
 	/// Variant that wraps over all other errors, unknown and undocumented
 	OtherError(String),
-	/// An error that is returned when either a [Keypair](vach::crypto::Keypair), Signature, [PublicKey](vach::crypto::PublicKey) or [SecretKey](vach::crypto::SecretKey) fail to deserialize.
+	/// An error that is returned when either a [Keypair](crate::crypto::Keypair), Signature, [PublicKey](crate::crypto::PublicKey) or [SecretKey](crate::crypto::SecretKey) fail to deserialize.
 	ParseError(String),
 	/// A thin wrapper over [io::Error](std::io::Error), captures all IO errors
 	IOError(io::Error),
@@ -18,38 +18,38 @@ pub enum InternalError {
 	MissingResourceError(String),
 	/// Thrown when a leaf with an identical ID to a queued leaf is add with the `Builder::add(---)` functions
 	LeafAppendError(String),
-	/// Thrown when no `Keypair` is provided and an encrypted [Leaf](vach::builder::Leaf) is encountered
+	/// Thrown when no `Keypair` is provided and an encrypted [Leaf](crate::builder::Leaf) is encountered
 	NoKeypairError(String),
 	/// Thrown when decryption or encryption fails
 	CryptoError(String),
-	/// Thrown when a link leaf aliases another link leaf, potentially causing a cyclic link error
-	CyclicLinkReferenceError(String, String),
-	/// Thrown when an attempt is made to set a bit within the first four bits(restricted) of a `Flag` instance
+	/// Thrown when an attempt is made to set a bit within the first four bits(restricted) of a [`Flags`](crate::prelude::Flags) instance
 	RestrictedFlagAccessError,
-	/// When a `Leaf` has an ID that is longer than `crate::MAX_ID_LENGTH`
+	/// When a [`Leaf`](crate::builder::Leaf) has an ID that is longer than `crate::MAX_ID_LENGTH`
 	IDSizeOverflowError(String),
 	/// Errors thrown during compression or decompression
 	DeCompressionError(String),
+	/// An error that is thrown when the current loader attempts to load an incompatible version, contains the incompatible version
+	IncompatibleArchiveVersionError(u16),
+	/// An error that is thrown when if `Mutex` is poisoned, when a message doesn't go though an `mspc::sync_channel` or other sync related issues
+	SyncError(String),
 }
 
 impl fmt::Display for InternalError {
 	fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
 		match self {
-			Self::OtherError(err) => write!(f, "{}", err),
+			Self::OtherError(err) => write!(f, "[VachError::GenericError] {}", err),
 			Self::ParseError(err) => write!(f, "[VachError::ParseError] {}", err),
-			Self::IOError(err) => write!(f, "[VachError::IOError] {}", err.to_string()),
+			Self::IOError(err) => write!(f, "[VachError::IOError] {}", err),
 			Self::ValidationError(err) => write!(f, "[VachError::ValidationError] {}", err),
 			Self::CryptoError(err) => write!(f, "[VachError::CryptoError]	{}", err),
 			Self::NoKeypairError(err) => write!(f, "{}", err),
 			Self::IDSizeOverflowError(id_part) => write!(f, "[VachError::IDSizeOverflowError] The maximum size of any ID is: {}. The leaf with ID: {} has an overflowing ID", crate::MAX_ID_LENGTH, id_part),
-			Self::CyclicLinkReferenceError(link, target) => {
-				let message = format!("[VachError::CyclicLinkReferenceError], link leafs can't point to other link leafs. Leaf: {} points to another link leaf: {}", link, target);
-				f.write_str(message.as_str())
-			},
 			Self::RestrictedFlagAccessError => write!(f, "[VachError::RestrictedFlagAccessError] Tried to set reserved bit(s)!"),
 			Self::MissingResourceError(id) => write!(f, "[VachError::MissingResourceError] {}", id),
 			Self::LeafAppendError(id) => write!(f, "[VachError::LeafAppendError] A leaf with the ID: {} already exists. Consider changing the ID to prevent collisions", id),
 			Self::DeCompressionError(err) => write!(f, "[VachError::DeCompressionError] Encountered an error during compression or decompression: {}", err),
+			Self::IncompatibleArchiveVersionError(version) => write!(f, "The provided archive source has version: {}. While the loader has a spec-version: {}. The current loader is incompatible!", version, crate::VERSION),
+			Self::SyncError(err) => write!(f, "[VachError::SyncError] {}", err),
 		}
 	}
 }
@@ -64,9 +64,6 @@ impl PartialEq for InternalError {
 			(Self::LeafAppendError(l0), Self::LeafAppendError(r0)) => l0 == r0,
 			(Self::NoKeypairError(l0), Self::NoKeypairError(r0)) => l0 == r0,
 			(Self::CryptoError(l0), Self::CryptoError(r0)) => l0 == r0,
-			(Self::CyclicLinkReferenceError(l0, l1), Self::CyclicLinkReferenceError(r0, r1)) => {
-				l0 == r0 && l1 == r1
-			}
 			(Self::IDSizeOverflowError(l0), Self::IDSizeOverflowError(r0)) => l0 == r0,
 			_ => core::mem::discriminant(self) == core::mem::discriminant(other),
 		}
