@@ -3,7 +3,7 @@ use crate::{
 };
 use std::{io::Read, fmt};
 
-/// Configures how `Leaf`s should be compressed.
+/// Configures how [`Leaf`]s should be compressed.
 /// Default is `CompressMode::Never`.
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum CompressMode {
@@ -21,18 +21,30 @@ impl Default for CompressMode {
 	}
 }
 
+#[cfg(feature = "multithreaded")]
+/// A toggle blanket-trait wrapping around `io::Read` allowing for seamless switching between single or multithreaded execution
+pub trait HandleTrait: Read + Send + Sync {}
+#[cfg(feature = "multithreaded")]
+impl<T: Read + Send + Sync> HandleTrait for T {}
+
+#[cfg(not(feature = "multithreaded"))]
+/// A toggle blanket-trait wrapping around `io::Read` allowing for seamless switching between single or multithreaded execution
+pub trait HandleTrait: Read {}
+#[cfg(not(feature = "multithreaded"))]
+impl<T: Read> HandleTrait for T {}
+
 /// A wrapper around an `io::Read` handle.
-/// Allows for multiple types of data implementing `io::Read` to be used under one structure.
+/// Allows for multiple types of data implementing `io::Read` to be used under one struct.
 /// Also used to configure how data will be processed and embedded into an write target.
 pub struct Leaf<'a> {
-	// The lifetime simply reflects to the `Builder`'s lifetime, meaning the handle must live longer than or the same as the Builder
-	pub(crate) handle: Box<dyn Read + 'a>,
+	// The lifetime simply reflects to the [`Builder`]'s lifetime, meaning the handle must live longer than or the same as the Builder
+	pub(crate) handle: Box<dyn HandleTrait + 'a>,
 
 	/// The `ID` under which the embedded data will be referenced
 	pub id: String,
 	/// The version of the content, allowing you to track obsolete data.
 	pub content_version: u8,
-	/// How a `Leaf` should be compressed
+	/// How a [`Leaf`] should be compressed
 	pub compress: CompressMode,
 	/// The specific compression algorithm to use
 	pub compression_algo: CompressionAlgorithm,
@@ -40,13 +52,10 @@ pub struct Leaf<'a> {
 	pub flags: Flags,
 	/// Use encryption when writing into the target.
 	pub encrypt: bool,
-	/// Whether to include a signature with this `Leaf`, defaults to false.
+	/// Whether to include a signature with this [`Leaf`], defaults to false.
 	/// If set to true then a hash generated and validated when loaded.
-	/// > *NOTE:* **Turning `sign` on severely hurts performance for making `Archive::fetch(---)`**.
+	/// > *NOTE:* **Turning `sign` on severely hurts the performance of `Archive::fetch(---)`**. This is because signature authentication is an intentionally taxing process, thus preventing brute-forcing of archives.
 	pub sign: bool,
-	/// If a `Leaf` has a link_mode of `Some("dw")`, then the leaf simply points to the Leaf with the ID "dw".
-	/// Use this if you want to have multiple entries aliasing the same data.
-	pub link_mode: Option<String>,
 }
 
 impl<'a> fmt::Debug for Leaf<'a> {
@@ -59,7 +68,6 @@ impl<'a> fmt::Debug for Leaf<'a> {
 			.field("flags", &self.flags)
 			.field("encrypt", &self.encrypt)
 			.field("sign", &self.sign)
-			.field("link_mode", &self.link_mode)
 			.field("compression_algo", &self.compression_algo)
 			.finish()
 	}
@@ -78,14 +86,13 @@ impl<'a> Default for Leaf<'a> {
 			compression_algo: CompressionAlgorithm::LZ4,
 			encrypt: false,
 			sign: false,
-			link_mode: None,
 		}
 	}
 }
 
 impl<'a> Leaf<'a> {
 	#[inline(always)]
-	/// Wrap a `Leaf` around the given handle.
+	/// Wrap a [`Leaf`] around the given handle.
 	/// Using the `Default` configuration.
 	///```
 	/// use vach::prelude::Leaf;
@@ -93,12 +100,16 @@ impl<'a> Leaf<'a> {
 	///
 	/// let leaf = Leaf::from_handle(Cursor::new(vec![]));
 	///```
-	pub fn from_handle<H: Read + 'a>(handle: H) -> Leaf<'a> {
+	pub fn from_handle<H: HandleTrait + 'a>(handle: H) -> Leaf<'a> {
 		Leaf {
 			handle: Box::new(handle),
 			..Default::default()
 		}
 	}
+	/// Consume the [Leaf] and return the underlying Boxed handle
+	pub fn into_inner(self) -> Box<dyn HandleTrait + 'a> {
+		self.handle
+	}
 	pub(crate) fn to_registry_entry(&self) -> RegistryEntry {
 		let mut entry = RegistryEntry::empty();
 		entry.content_version = self.content_version;
@@ -106,7 +117,7 @@ impl<'a> Leaf<'a> {
 		entry
 	}
 
-	/// Copy all fields from another `Leaf`, except for `handle`, `link_mode` and `id`
+	/// Copy all fields from another [`Leaf`], except for `handle` and `id`
 	/// Meant to be used like a setter:
 	/// ```rust
 	/// use std::io::Cursor;
@@ -123,13 +134,12 @@ impl<'a> Leaf<'a> {
 		Leaf {
 			handle: self.handle,
 			id: self.id,
-			link_mode: self.link_mode,
 			..*other
 		}
 	}
 
 	// Setters
-	/// Setter used to set the `CompressMode` of a `Leaf`
+	/// Setter used to set the [`CompressMode`] of a [`Leaf`]
 	/// ```rust
 	/// use vach::prelude::{Leaf, CompressMode};
 	///
@@ -139,7 +149,7 @@ impl<'a> Leaf<'a> {
 		self.compress = compress;
 		self
 	}
-	/// Setter used to set the `content_version` of a `Leaf`
+	/// Setter used to set the `content_version` of a [`Leaf`]
 	/// ```rust
 	/// use vach::prelude::{Leaf};
 	///
@@ -149,7 +159,7 @@ impl<'a> Leaf<'a> {
 		self.content_version = content_version;
 		self
 	}
-	/// Setter used to set the `id` field of a `Leaf`
+	/// Setter used to set the `id` field of a [`Leaf`]
 	/// ```rust
 	/// use vach::prelude::{Leaf};
 	///
@@ -159,7 +169,7 @@ impl<'a> Leaf<'a> {
 		self.id = id.to_string();
 		self
 	}
-	/// Setter used to set the `Flags` field of a `Leaf`
+	/// Setter used to set the [`flags`](crate::builder::Flags) field of a [`Leaf`]
 	/// ```rust
 	/// use vach::prelude::{Leaf, Flags};
 	///
@@ -171,7 +181,7 @@ impl<'a> Leaf<'a> {
 	}
 	/// Setter for the `encrypt` field
 	///```
-	///use vach::prelude::Leaf;
+	/// use vach::prelude::Leaf;
 	/// let config = Leaf::default().encrypt(true);
 	///```
 	pub fn encrypt(mut self, encrypt: bool) -> Self {
@@ -181,7 +191,7 @@ impl<'a> Leaf<'a> {
 
 	/// Setter for the `sign` field
 	///```
-	///use vach::prelude::Leaf;
+	/// use vach::prelude::Leaf;
 	/// let config = Leaf::default().sign(true);
 	///```
 	pub fn sign(mut self, sign: bool) -> Self {
@@ -189,16 +199,6 @@ impl<'a> Leaf<'a> {
 		self
 	}
 
-	/// Setter for the `link_mode` field
-	///```
-	///use vach::prelude::Leaf;
-	/// let config = Leaf::default().link_mode(Some("default.tx".to_string()));
-	///```
-	pub fn link_mode(mut self, link_mode: Option<String>) -> Self {
-		self.link_mode = link_mode;
-		self
-	}
-
 	/// Setter for the `compression_algo` field
 	pub fn compression_algo(mut self, compression_algo: CompressionAlgorithm) -> Self {
 		self.compression_algo = compression_algo;
